<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>CoverManager</name>
    <message>
        <location filename="../covermanager.cpp" line="35"/>
        <source>Show Cover</source>
        <translation>Toon albumhoes</translation>
    </message>
    <message>
        <location filename="../covermanager.cpp" line="36"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
</context>
<context>
    <name>CoverManagerFactory</name>
    <message>
        <location filename="../covermanagerfactory.cpp" line="30"/>
        <source>Cover Manager Plugin</source>
        <translation>Albumhoes Module</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="50"/>
        <source>About Cover Manager Plugin</source>
        <translation>Over de Albumhoes Module</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="51"/>
        <source>Qmmp Cover Manager Plugin</source>
        <translation>Albumhoes Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>CoverWidget</name>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Bewaar als...</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="38"/>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="40"/>
        <source>Actual Size</source>
        <translation>Werkelijke grootte</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="41"/>
        <source>128x128</source>
        <translation>128x128</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="42"/>
        <source>256x256</source>
        <translation>256x256</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="43"/>
        <source>512x512</source>
        <translation>512x512</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="44"/>
        <source>1024x1024</source>
        <translation>1024x1024</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>Alt+F4</source>
        <translation>Alt+F4</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="90"/>
        <source>Save Cover As</source>
        <translation>Bewaar Albumhoes Als</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="92"/>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
</context>
</TS>
